'''_4692.py

WormGearSetCompoundModalAnalysisAtASpeed
'''


from typing import List

from mastapy.system_model.part_model.gears import _2088
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_speed.compound import _4690, _4691, _4628
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_speed import _4571
from mastapy._internal.python_net import python_net_import

_WORM_GEAR_SET_COMPOUND_MODAL_ANALYSIS_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtASpeed.Compound', 'WormGearSetCompoundModalAnalysisAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('WormGearSetCompoundModalAnalysisAtASpeed',)


class WormGearSetCompoundModalAnalysisAtASpeed(_4628.GearSetCompoundModalAnalysisAtASpeed):
    '''WormGearSetCompoundModalAnalysisAtASpeed

    This is a mastapy class.
    '''

    TYPE = _WORM_GEAR_SET_COMPOUND_MODAL_ANALYSIS_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'WormGearSetCompoundModalAnalysisAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2088.WormGearSet':
        '''WormGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2088.WormGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2088.WormGearSet':
        '''WormGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2088.WormGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def worm_gears_compound_modal_analysis_at_a_speed(self) -> 'List[_4690.WormGearCompoundModalAnalysisAtASpeed]':
        '''List[WormGearCompoundModalAnalysisAtASpeed]: 'WormGearsCompoundModalAnalysisAtASpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.WormGearsCompoundModalAnalysisAtASpeed, constructor.new(_4690.WormGearCompoundModalAnalysisAtASpeed))
        return value

    @property
    def worm_meshes_compound_modal_analysis_at_a_speed(self) -> 'List[_4691.WormGearMeshCompoundModalAnalysisAtASpeed]':
        '''List[WormGearMeshCompoundModalAnalysisAtASpeed]: 'WormMeshesCompoundModalAnalysisAtASpeed' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.WormMeshesCompoundModalAnalysisAtASpeed, constructor.new(_4691.WormGearMeshCompoundModalAnalysisAtASpeed))
        return value

    @property
    def load_case_analyses_ready(self) -> 'List[_4571.WormGearSetModalAnalysisAtASpeed]':
        '''List[WormGearSetModalAnalysisAtASpeed]: 'LoadCaseAnalysesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LoadCaseAnalysesReady, constructor.new(_4571.WormGearSetModalAnalysisAtASpeed))
        return value

    @property
    def assembly_modal_analysis_at_a_speed_load_cases(self) -> 'List[_4571.WormGearSetModalAnalysisAtASpeed]':
        '''List[WormGearSetModalAnalysisAtASpeed]: 'AssemblyModalAnalysisAtASpeedLoadCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyModalAnalysisAtASpeedLoadCases, constructor.new(_4571.WormGearSetModalAnalysisAtASpeed))
        return value



'''_67.py

ISOLubricantType
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_ISO_LUBRICANT_TYPE = python_net_import('SMT.MastaAPI.Materials', 'ISOLubricantType')


__docformat__ = 'restructuredtext en'
__all__ = ('ISOLubricantType',)


class ISOLubricantType(Enum):
    '''ISOLubricantType

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _ISO_LUBRICANT_TYPE

    __hash__ = None

    MINERAL_OIL = 0
    WATER_SOLUBLE_POLYGLYCOL = 1
    NON_WATER_SOLUBLE_POLYGLYCOL = 2
    POLYALPHAOLEFIN = 3
    PHOSPHATE_ESTER = 4
    TRACTION_FLUID = 5



'''_2131.py

SpringDamperHalf
'''


from mastapy.system_model.part_model.couplings import _2116
from mastapy._internal.python_net import python_net_import

_SPRING_DAMPER_HALF = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Couplings', 'SpringDamperHalf')


__docformat__ = 'restructuredtext en'
__all__ = ('SpringDamperHalf',)


class SpringDamperHalf(_2116.CouplingHalf):
    '''SpringDamperHalf

    This is a mastapy class.
    '''

    TYPE = _SPRING_DAMPER_HALF

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SpringDamperHalf.TYPE'):
        super().__init__(instance_to_wrap)



'''_5280.py

ConceptGearSetGearWhineAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2058
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6074
from mastapy.system_model.analyses_and_results.system_deflections import _2233
from mastapy.system_model.analyses_and_results.gear_whine_analyses import _5278, _5279, _5318
from mastapy._internal.python_net import python_net_import

_CONCEPT_GEAR_SET_GEAR_WHINE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.GearWhineAnalyses', 'ConceptGearSetGearWhineAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('ConceptGearSetGearWhineAnalysis',)


class ConceptGearSetGearWhineAnalysis(_5318.GearSetGearWhineAnalysis):
    '''ConceptGearSetGearWhineAnalysis

    This is a mastapy class.
    '''

    TYPE = _CONCEPT_GEAR_SET_GEAR_WHINE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConceptGearSetGearWhineAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def assembly_design(self) -> '_2058.ConceptGearSet':
        '''ConceptGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2058.ConceptGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def assembly_load_case(self) -> '_6074.ConceptGearSetLoadCase':
        '''ConceptGearSetLoadCase: 'AssemblyLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6074.ConceptGearSetLoadCase)(self.wrapped.AssemblyLoadCase) if self.wrapped.AssemblyLoadCase else None

    @property
    def system_deflection_results(self) -> '_2233.ConceptGearSetSystemDeflection':
        '''ConceptGearSetSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2233.ConceptGearSetSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def gears_gear_whine_analysis(self) -> 'List[_5278.ConceptGearGearWhineAnalysis]':
        '''List[ConceptGearGearWhineAnalysis]: 'GearsGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.GearsGearWhineAnalysis, constructor.new(_5278.ConceptGearGearWhineAnalysis))
        return value

    @property
    def concept_gears_gear_whine_analysis(self) -> 'List[_5278.ConceptGearGearWhineAnalysis]':
        '''List[ConceptGearGearWhineAnalysis]: 'ConceptGearsGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptGearsGearWhineAnalysis, constructor.new(_5278.ConceptGearGearWhineAnalysis))
        return value

    @property
    def meshes_gear_whine_analysis(self) -> 'List[_5279.ConceptGearMeshGearWhineAnalysis]':
        '''List[ConceptGearMeshGearWhineAnalysis]: 'MeshesGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.MeshesGearWhineAnalysis, constructor.new(_5279.ConceptGearMeshGearWhineAnalysis))
        return value

    @property
    def concept_meshes_gear_whine_analysis(self) -> 'List[_5279.ConceptGearMeshGearWhineAnalysis]':
        '''List[ConceptGearMeshGearWhineAnalysis]: 'ConceptMeshesGearWhineAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptMeshesGearWhineAnalysis, constructor.new(_5279.ConceptGearMeshGearWhineAnalysis))
        return value



'''_4671.py

SpringDamperHalfCompoundModalAnalysisAtASpeed
'''


from typing import List

from mastapy.system_model.part_model.couplings import _2131
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_speed import _4549
from mastapy.system_model.analyses_and_results.modal_analyses_at_a_speed.compound import _4612
from mastapy._internal.python_net import python_net_import

_SPRING_DAMPER_HALF_COMPOUND_MODAL_ANALYSIS_AT_A_SPEED = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtASpeed.Compound', 'SpringDamperHalfCompoundModalAnalysisAtASpeed')


__docformat__ = 'restructuredtext en'
__all__ = ('SpringDamperHalfCompoundModalAnalysisAtASpeed',)


class SpringDamperHalfCompoundModalAnalysisAtASpeed(_4612.CouplingHalfCompoundModalAnalysisAtASpeed):
    '''SpringDamperHalfCompoundModalAnalysisAtASpeed

    This is a mastapy class.
    '''

    TYPE = _SPRING_DAMPER_HALF_COMPOUND_MODAL_ANALYSIS_AT_A_SPEED

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SpringDamperHalfCompoundModalAnalysisAtASpeed.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2131.SpringDamperHalf':
        '''SpringDamperHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2131.SpringDamperHalf)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def load_case_analyses_ready(self) -> 'List[_4549.SpringDamperHalfModalAnalysisAtASpeed]':
        '''List[SpringDamperHalfModalAnalysisAtASpeed]: 'LoadCaseAnalysesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LoadCaseAnalysesReady, constructor.new(_4549.SpringDamperHalfModalAnalysisAtASpeed))
        return value

    @property
    def component_modal_analysis_at_a_speed_load_cases(self) -> 'List[_4549.SpringDamperHalfModalAnalysisAtASpeed]':
        '''List[SpringDamperHalfModalAnalysisAtASpeed]: 'ComponentModalAnalysisAtASpeedLoadCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentModalAnalysisAtASpeedLoadCases, constructor.new(_4549.SpringDamperHalfModalAnalysisAtASpeed))
        return value



'''_3329.py

TorqueConverterTurbinePowerFlow
'''


from mastapy.system_model.part_model.couplings import _2140
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6199
from mastapy.system_model.analyses_and_results.power_flows import _3249
from mastapy._internal.python_net import python_net_import

_TORQUE_CONVERTER_TURBINE_POWER_FLOW = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.PowerFlows', 'TorqueConverterTurbinePowerFlow')


__docformat__ = 'restructuredtext en'
__all__ = ('TorqueConverterTurbinePowerFlow',)


class TorqueConverterTurbinePowerFlow(_3249.CouplingHalfPowerFlow):
    '''TorqueConverterTurbinePowerFlow

    This is a mastapy class.
    '''

    TYPE = _TORQUE_CONVERTER_TURBINE_POWER_FLOW

    __hash__ = None

    def __init__(self, instance_to_wrap: 'TorqueConverterTurbinePowerFlow.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2140.TorqueConverterTurbine':
        '''TorqueConverterTurbine: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2140.TorqueConverterTurbine)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6199.TorqueConverterTurbineLoadCase':
        '''TorqueConverterTurbineLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6199.TorqueConverterTurbineLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None



'''_2108.py

BeltDrive
'''


from typing import List

from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy.system_model.part_model.couplings import _2109, _2121
from mastapy.system_model.connections_and_sockets import _1830
from mastapy.system_model.part_model import _2014
from mastapy._internal.python_net import python_net_import

_BELT_DRIVE = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Couplings', 'BeltDrive')


__docformat__ = 'restructuredtext en'
__all__ = ('BeltDrive',)


class BeltDrive(_2014.SpecialisedAssembly):
    '''BeltDrive

    This is a mastapy class.
    '''

    TYPE = _BELT_DRIVE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BeltDrive.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def stiffness(self) -> 'float':
        '''float: 'Stiffness' is the original name of this property.'''

        return self.wrapped.Stiffness

    @stiffness.setter
    def stiffness(self, value: 'float'):
        self.wrapped.Stiffness = float(value) if value else 0.0

    @property
    def stiffness_for_unit_length(self) -> 'float':
        '''float: 'StiffnessForUnitLength' is the original name of this property.'''

        return self.wrapped.StiffnessForUnitLength

    @stiffness_for_unit_length.setter
    def stiffness_for_unit_length(self, value: 'float'):
        self.wrapped.StiffnessForUnitLength = float(value) if value else 0.0

    @property
    def specify_stiffness_for_unit_length(self) -> 'bool':
        '''bool: 'SpecifyStiffnessForUnitLength' is the original name of this property.'''

        return self.wrapped.SpecifyStiffnessForUnitLength

    @specify_stiffness_for_unit_length.setter
    def specify_stiffness_for_unit_length(self, value: 'bool'):
        self.wrapped.SpecifyStiffnessForUnitLength = bool(value) if value else False

    @property
    def pre_tension(self) -> 'float':
        '''float: 'PreTension' is the original name of this property.'''

        return self.wrapped.PreTension

    @pre_tension.setter
    def pre_tension(self, value: 'float'):
        self.wrapped.PreTension = float(value) if value else 0.0

    @property
    def belt_mass_per_unit_length(self) -> 'float':
        '''float: 'BeltMassPerUnitLength' is the original name of this property.'''

        return self.wrapped.BeltMassPerUnitLength

    @belt_mass_per_unit_length.setter
    def belt_mass_per_unit_length(self, value: 'float'):
        self.wrapped.BeltMassPerUnitLength = float(value) if value else 0.0

    @property
    def type_of_belt(self) -> '_2109.BeltDriveType':
        '''BeltDriveType: 'TypeOfBelt' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.TypeOfBelt)
        return constructor.new(_2109.BeltDriveType)(value) if value else None

    @type_of_belt.setter
    def type_of_belt(self, value: '_2109.BeltDriveType'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.TypeOfBelt = value

    @property
    def belt_mass(self) -> 'float':
        '''float: 'BeltMass' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BeltMass

    @property
    def belt_length(self) -> 'float':
        '''float: 'BeltLength' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BeltLength

    @property
    def pulleys(self) -> 'List[_2121.Pulley]':
        '''List[Pulley]: 'Pulleys' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Pulleys, constructor.new(_2121.Pulley))
        return value

    @property
    def belt_connections(self) -> 'List[_1830.BeltConnection]':
        '''List[BeltConnection]: 'BeltConnections' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.BeltConnections, constructor.new(_1830.BeltConnection))
        return value



'''_333.py

ConceptGearMeshDutyCycleRating
'''


from mastapy.gears.rating import _168
from mastapy._internal.python_net import python_net_import

_CONCEPT_GEAR_MESH_DUTY_CYCLE_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Concept', 'ConceptGearMeshDutyCycleRating')


__docformat__ = 'restructuredtext en'
__all__ = ('ConceptGearMeshDutyCycleRating',)


class ConceptGearMeshDutyCycleRating(_168.MeshDutyCycleRating):
    '''ConceptGearMeshDutyCycleRating

    This is a mastapy class.
    '''

    TYPE = _CONCEPT_GEAR_MESH_DUTY_CYCLE_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConceptGearMeshDutyCycleRating.TYPE'):
        super().__init__(instance_to_wrap)



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3597 import AbstractAssemblyCompoundParametricStudyTool
    from ._3598 import AbstractShaftOrHousingCompoundParametricStudyTool
    from ._3599 import AGMAGleasonConicalGearCompoundParametricStudyTool
    from ._3600 import AGMAGleasonConicalGearMeshCompoundParametricStudyTool
    from ._3601 import AGMAGleasonConicalGearSetCompoundParametricStudyTool
    from ._3602 import AssemblyCompoundParametricStudyTool
    from ._3603 import BearingCompoundParametricStudyTool
    from ._3604 import BeltConnectionCompoundParametricStudyTool
    from ._3605 import BeltDriveCompoundParametricStudyTool
    from ._3606 import BevelDifferentialGearCompoundParametricStudyTool
    from ._3607 import BevelDifferentialGearMeshCompoundParametricStudyTool
    from ._3608 import BevelDifferentialGearSetCompoundParametricStudyTool
    from ._3609 import BevelDifferentialPlanetGearCompoundParametricStudyTool
    from ._3610 import BevelDifferentialSunGearCompoundParametricStudyTool
    from ._3611 import BevelGearCompoundParametricStudyTool
    from ._3612 import BevelGearMeshCompoundParametricStudyTool
    from ._3613 import BevelGearSetCompoundParametricStudyTool
    from ._3614 import BoltCompoundParametricStudyTool
    from ._3615 import BoltedJointCompoundParametricStudyTool
    from ._3616 import ClutchCompoundParametricStudyTool
    from ._3617 import ClutchConnectionCompoundParametricStudyTool
    from ._3618 import ClutchHalfCompoundParametricStudyTool
    from ._3619 import CoaxialConnectionCompoundParametricStudyTool
    from ._3620 import ComponentCompoundParametricStudyTool
    from ._3621 import ConceptCouplingCompoundParametricStudyTool
    from ._3622 import ConceptCouplingConnectionCompoundParametricStudyTool
    from ._3623 import ConceptCouplingHalfCompoundParametricStudyTool
    from ._3624 import ConceptGearCompoundParametricStudyTool
    from ._3625 import ConceptGearMeshCompoundParametricStudyTool
    from ._3626 import ConceptGearSetCompoundParametricStudyTool
    from ._3627 import ConicalGearCompoundParametricStudyTool
    from ._3628 import ConicalGearMeshCompoundParametricStudyTool
    from ._3629 import ConicalGearSetCompoundParametricStudyTool
    from ._3630 import ConnectionCompoundParametricStudyTool
    from ._3631 import ConnectorCompoundParametricStudyTool
    from ._3632 import CouplingCompoundParametricStudyTool
    from ._3633 import CouplingConnectionCompoundParametricStudyTool
    from ._3634 import CouplingHalfCompoundParametricStudyTool
    from ._3635 import CVTBeltConnectionCompoundParametricStudyTool
    from ._3636 import CVTCompoundParametricStudyTool
    from ._3637 import CVTPulleyCompoundParametricStudyTool
    from ._3638 import CylindricalGearCompoundParametricStudyTool
    from ._3639 import CylindricalGearMeshCompoundParametricStudyTool
    from ._3640 import CylindricalGearSetCompoundParametricStudyTool
    from ._3641 import CylindricalPlanetGearCompoundParametricStudyTool
    from ._3642 import DatumCompoundParametricStudyTool
    from ._3643 import ExternalCADModelCompoundParametricStudyTool
    from ._3644 import FaceGearCompoundParametricStudyTool
    from ._3645 import FaceGearMeshCompoundParametricStudyTool
    from ._3646 import FaceGearSetCompoundParametricStudyTool
    from ._3647 import FlexiblePinAssemblyCompoundParametricStudyTool
    from ._3648 import GearCompoundParametricStudyTool
    from ._3649 import GearMeshCompoundParametricStudyTool
    from ._3650 import GearSetCompoundParametricStudyTool
    from ._3651 import GuideDxfModelCompoundParametricStudyTool
    from ._3652 import HypoidGearCompoundParametricStudyTool
    from ._3653 import HypoidGearMeshCompoundParametricStudyTool
    from ._3654 import HypoidGearSetCompoundParametricStudyTool
    from ._3655 import ImportedFEComponentCompoundParametricStudyTool
    from ._3656 import InterMountableComponentConnectionCompoundParametricStudyTool
    from ._3657 import KlingelnbergCycloPalloidConicalGearCompoundParametricStudyTool
    from ._3658 import KlingelnbergCycloPalloidConicalGearMeshCompoundParametricStudyTool
    from ._3659 import KlingelnbergCycloPalloidConicalGearSetCompoundParametricStudyTool
    from ._3660 import KlingelnbergCycloPalloidHypoidGearCompoundParametricStudyTool
    from ._3661 import KlingelnbergCycloPalloidHypoidGearMeshCompoundParametricStudyTool
    from ._3662 import KlingelnbergCycloPalloidHypoidGearSetCompoundParametricStudyTool
    from ._3663 import KlingelnbergCycloPalloidSpiralBevelGearCompoundParametricStudyTool
    from ._3664 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundParametricStudyTool
    from ._3665 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundParametricStudyTool
    from ._3666 import MassDiscCompoundParametricStudyTool
    from ._3667 import MeasurementComponentCompoundParametricStudyTool
    from ._3668 import MountableComponentCompoundParametricStudyTool
    from ._3669 import OilSealCompoundParametricStudyTool
    from ._3670 import PartCompoundParametricStudyTool
    from ._3671 import PartToPartShearCouplingCompoundParametricStudyTool
    from ._3672 import PartToPartShearCouplingConnectionCompoundParametricStudyTool
    from ._3673 import PartToPartShearCouplingHalfCompoundParametricStudyTool
    from ._3674 import PlanetaryConnectionCompoundParametricStudyTool
    from ._3675 import PlanetaryGearSetCompoundParametricStudyTool
    from ._3676 import PlanetCarrierCompoundParametricStudyTool
    from ._3677 import PointLoadCompoundParametricStudyTool
    from ._3678 import PowerLoadCompoundParametricStudyTool
    from ._3679 import PulleyCompoundParametricStudyTool
    from ._3680 import RollingRingAssemblyCompoundParametricStudyTool
    from ._3681 import RollingRingCompoundParametricStudyTool
    from ._3682 import RollingRingConnectionCompoundParametricStudyTool
    from ._3683 import RootAssemblyCompoundParametricStudyTool
    from ._3684 import ShaftCompoundParametricStudyTool
    from ._3685 import ShaftHubConnectionCompoundParametricStudyTool
    from ._3686 import ShaftToMountableComponentConnectionCompoundParametricStudyTool
    from ._3687 import SpecialisedAssemblyCompoundParametricStudyTool
    from ._3688 import SpiralBevelGearCompoundParametricStudyTool
    from ._3689 import SpiralBevelGearMeshCompoundParametricStudyTool
    from ._3690 import SpiralBevelGearSetCompoundParametricStudyTool
    from ._3691 import SpringDamperCompoundParametricStudyTool
    from ._3692 import SpringDamperConnectionCompoundParametricStudyTool
    from ._3693 import SpringDamperHalfCompoundParametricStudyTool
    from ._3694 import StraightBevelDiffGearCompoundParametricStudyTool
    from ._3695 import StraightBevelDiffGearMeshCompoundParametricStudyTool
    from ._3696 import StraightBevelDiffGearSetCompoundParametricStudyTool
    from ._3697 import StraightBevelGearCompoundParametricStudyTool
    from ._3698 import StraightBevelGearMeshCompoundParametricStudyTool
    from ._3699 import StraightBevelGearSetCompoundParametricStudyTool
    from ._3700 import StraightBevelPlanetGearCompoundParametricStudyTool
    from ._3701 import StraightBevelSunGearCompoundParametricStudyTool
    from ._3702 import SynchroniserCompoundParametricStudyTool
    from ._3703 import SynchroniserHalfCompoundParametricStudyTool
    from ._3704 import SynchroniserPartCompoundParametricStudyTool
    from ._3705 import SynchroniserSleeveCompoundParametricStudyTool
    from ._3706 import TorqueConverterCompoundParametricStudyTool
    from ._3707 import TorqueConverterConnectionCompoundParametricStudyTool
    from ._3708 import TorqueConverterPumpCompoundParametricStudyTool
    from ._3709 import TorqueConverterTurbineCompoundParametricStudyTool
    from ._3710 import UnbalancedMassCompoundParametricStudyTool
    from ._3711 import VirtualComponentCompoundParametricStudyTool
    from ._3712 import WormGearCompoundParametricStudyTool
    from ._3713 import WormGearMeshCompoundParametricStudyTool
    from ._3714 import WormGearSetCompoundParametricStudyTool
    from ._3715 import ZerolBevelGearCompoundParametricStudyTool
    from ._3716 import ZerolBevelGearMeshCompoundParametricStudyTool
    from ._3717 import ZerolBevelGearSetCompoundParametricStudyTool



'''_1932.py

ImportedFE
'''


from typing import Callable, List

from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import overridable, list_with_selected_item, enum_with_selected_value
from mastapy.utility.units_and_measurements import _1153
from mastapy.system_model.imported_fes import (
    _1913, _1945, _1969, _1907,
    _1909, _1970, _1965, _1944,
    _1905, _1929, _1931, _1951,
    _1950, _1947, _1948, _1949
)
from mastapy._internal.python_net import python_net_import
from mastapy.system_model.part_model import _1990, _1986, _1998
from mastapy.nodal_analysis import _1367, _1370
from mastapy.nodal_analysis.component_mode_synthesis import _1491
from mastapy.system_model import _1806
from mastapy.math_utility import _1061
from mastapy.materials import _44, _88
from mastapy.system_model.part_model.shaft_model import _2019
from mastapy.math_utility.measured_vectors import _1116
from mastapy import _6498

_DATABASE_WITH_SELECTED_ITEM = python_net_import('SMT.MastaAPI.UtilityGUI.Databases', 'DatabaseWithSelectedItem')
_IMPORTED_FE = python_net_import('SMT.MastaAPI.SystemModel.ImportedFEs', 'ImportedFE')


__docformat__ = 'restructuredtext en'
__all__ = ('ImportedFE',)


class ImportedFE(_1370.FEStiffness):
    '''ImportedFE

    This is a mastapy class.
    '''

    TYPE = _IMPORTED_FE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ImportedFE.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def external_fe_forces_are_from_gravity_only(self) -> 'bool':
        '''bool: 'ExternalFEForcesAreFromGravityOnly' is the original name of this property.'''

        return self.wrapped.ExternalFEForcesAreFromGravityOnly

    @external_fe_forces_are_from_gravity_only.setter
    def external_fe_forces_are_from_gravity_only(self, value: 'bool'):
        self.wrapped.ExternalFEForcesAreFromGravityOnly = bool(value) if value else False

    @property
    def housing_is_grounded(self) -> 'bool':
        '''bool: 'HousingIsGrounded' is the original name of this property.'''

        return self.wrapped.HousingIsGrounded

    @housing_is_grounded.setter
    def housing_is_grounded(self, value: 'bool'):
        self.wrapped.HousingIsGrounded = bool(value) if value else False

    @property
    def check_fe_has_internal_modes_before_nvh_analysis(self) -> 'bool':
        '''bool: 'CheckFEHasInternalModesBeforeNVHAnalysis' is the original name of this property.'''

        return self.wrapped.CheckFEHasInternalModesBeforeNVHAnalysis

    @check_fe_has_internal_modes_before_nvh_analysis.setter
    def check_fe_has_internal_modes_before_nvh_analysis(self, value: 'bool'):
        self.wrapped.CheckFEHasInternalModesBeforeNVHAnalysis = bool(value) if value else False

    @property
    def expected_number_of_rigid_body_modes(self) -> 'overridable.Overridable_int':
        '''overridable.Overridable_int: 'ExpectedNumberOfRigidBodyModes' is the original name of this property.'''

        return constructor.new(overridable.Overridable_int)(self.wrapped.ExpectedNumberOfRigidBodyModes) if self.wrapped.ExpectedNumberOfRigidBodyModes else None

    @expected_number_of_rigid_body_modes.setter
    def expected_number_of_rigid_body_modes(self, value: 'overridable.Overridable_int.implicit_type()'):
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0)
        self.wrapped.ExpectedNumberOfRigidBodyModes = value

    @property
    def actual_number_of_rigid_body_modes(self) -> 'int':
        '''int: 'ActualNumberOfRigidBodyModes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ActualNumberOfRigidBodyModes

    @property
    def is_housing(self) -> 'bool':
        '''bool: 'IsHousing' is the original name of this property.'''

        return self.wrapped.IsHousing

    @is_housing.setter
    def is_housing(self, value: 'bool'):
        self.wrapped.IsHousing = bool(value) if value else False

    @property
    def distance_display_unit(self) -> 'list_with_selected_item.ListWithSelectedItem_Unit':
        '''list_with_selected_item.ListWithSelectedItem_Unit: 'DistanceDisplayUnit' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_Unit)(self.wrapped.DistanceDisplayUnit) if self.wrapped.DistanceDisplayUnit else None

    @distance_display_unit.setter
    def distance_display_unit(self, value: 'list_with_selected_item.ListWithSelectedItem_Unit.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_Unit.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_Unit.implicit_type()
        value = wrapper_type[enclosed_type](value.wrapped if value else None)
        self.wrapped.DistanceDisplayUnit = value

    @property
    def force_display_unit(self) -> 'list_with_selected_item.ListWithSelectedItem_Unit':
        '''list_with_selected_item.ListWithSelectedItem_Unit: 'ForceDisplayUnit' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_Unit)(self.wrapped.ForceDisplayUnit) if self.wrapped.ForceDisplayUnit else None

    @force_display_unit.setter
    def force_display_unit(self, value: 'list_with_selected_item.ListWithSelectedItem_Unit.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_Unit.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_Unit.implicit_type()
        value = wrapper_type[enclosed_type](value.wrapped if value else None)
        self.wrapped.ForceDisplayUnit = value

    @property
    def non_condensation_node_size(self) -> 'int':
        '''int: 'NonCondensationNodeSize' is the original name of this property.'''

        return self.wrapped.NonCondensationNodeSize

    @non_condensation_node_size.setter
    def non_condensation_node_size(self, value: 'int'):
        self.wrapped.NonCondensationNodeSize = int(value) if value else 0

    @property
    def auto_connect_external_nodes(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'AutoConnectExternalNodes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AutoConnectExternalNodes

    @property
    def default_node_creation_options(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'DefaultNodeCreationOptions' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DefaultNodeCreationOptions

    @property
    def angular_alignment_tolerance(self) -> 'float':
        '''float: 'AngularAlignmentTolerance' is the original name of this property.'''

        return self.wrapped.AngularAlignmentTolerance

    @angular_alignment_tolerance.setter
    def angular_alignment_tolerance(self, value: 'float'):
        self.wrapped.AngularAlignmentTolerance = float(value) if value else 0.0

    @property
    def bearing_node_alignment(self) -> '_1913.BearingNodeAlignmentOption':
        '''BearingNodeAlignmentOption: 'BearingNodeAlignment' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.BearingNodeAlignment)
        return constructor.new(_1913.BearingNodeAlignmentOption)(value) if value else None

    @bearing_node_alignment.setter
    def bearing_node_alignment(self, value: '_1913.BearingNodeAlignmentOption'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.BearingNodeAlignment = value

    @property
    def comment(self) -> 'str':
        '''str: 'Comment' is the original name of this property.'''

        return self.wrapped.Comment

    @comment.setter
    def comment(self, value: 'str'):
        self.wrapped.Comment = str(value) if value else None

    @property
    def polar_inertia(self) -> 'float':
        '''float: 'PolarInertia' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PolarInertia

    @property
    def torque_transmission_relative_tolerance(self) -> 'float':
        '''float: 'TorqueTransmissionRelativeTolerance' is the original name of this property.'''

        return self.wrapped.TorqueTransmissionRelativeTolerance

    @torque_transmission_relative_tolerance.setter
    def torque_transmission_relative_tolerance(self, value: 'float'):
        self.wrapped.TorqueTransmissionRelativeTolerance = float(value) if value else 0.0

    @property
    def type_(self) -> 'enum_with_selected_value.EnumWithSelectedValue_ImportedFEType':
        '''enum_with_selected_value.EnumWithSelectedValue_ImportedFEType: 'Type' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_ImportedFEType.implicit_type()
        return enum_with_selected_value_runtime.create(self.wrapped.Type, value) if self.wrapped.Type else None

    @type_.setter
    def type_(self, value: 'enum_with_selected_value.EnumWithSelectedValue_ImportedFEType.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_ImportedFEType.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value if value else None)
        self.wrapped.Type = value

    @property
    def full_fe_model_mesh_path(self) -> 'str':
        '''str: 'FullFEModelMeshPath' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FullFEModelMeshPath

    @property
    def full_fe_model_vectors_path(self) -> 'str':
        '''str: 'FullFEModelVectorsPath' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FullFEModelVectorsPath

    @property
    def material(self) -> 'str':
        '''str: 'Material' is the original name of this property.'''

        return self.wrapped.Material.SelectedItemName

    @material.setter
    def material(self, value: 'str'):
        self.wrapped.Material.SetSelectedItem(str(value) if value else None)

    @property
    def thermal_expansion_option(self) -> 'enum_with_selected_value.EnumWithSelectedValue_ThermalExpansionOption':
        '''enum_with_selected_value.EnumWithSelectedValue_ThermalExpansionOption: 'ThermalExpansionOption' is the original name of this property.'''

        value = enum_with_selected_value.EnumWithSelectedValue_ThermalExpansionOption.implicit_type()
        return enum_with_selected_value_runtime.create(self.wrapped.ThermalExpansionOption, value) if self.wrapped.ThermalExpansionOption else None

    @thermal_expansion_option.setter
    def thermal_expansion_option(self, value: 'enum_with_selected_value.EnumWithSelectedValue_ThermalExpansionOption.implicit_type()'):
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_ThermalExpansionOption.implicit_type()
        value = conversion.mp_to_pn_enum(value)
        value = wrapper_type[enclosed_type](value if value else None)
        self.wrapped.ThermalExpansionOption = value

    @property
    def thermal_expansion_status(self) -> 'str':
        '''str: 'ThermalExpansionStatus' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ThermalExpansionStatus

    @property
    def add_geometry(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'AddGeometry' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AddGeometry

    @property
    def import_node_positions(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'ImportNodePositions' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ImportNodePositions

    @property
    def create_fe_volume_mesh(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'CreateFEVolumeMesh' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CreateFEVolumeMesh

    @property
    def update_gear_teeth_mesh(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'UpdateGearTeethMesh' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.UpdateGearTeethMesh

    @property
    def import_reduced_stiffness(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'ImportReducedStiffness' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ImportReducedStiffness

    @property
    def open_existing_smtfe_file(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'OpenExistingSMTFEFile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.OpenExistingSMTFEFile

    @property
    def re_import_external_fe_mesh(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'ReImportExternalFEMesh' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ReImportExternalFEMesh

    @property
    def perform_reduction(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'PerformReduction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PerformReduction

    @property
    def number_of_condensation_nodes_in_reduced_model(self) -> 'int':
        '''int: 'NumberOfCondensationNodesInReducedModel' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfCondensationNodesInReducedModel

    @property
    def number_of_condensation_nodes(self) -> 'int':
        '''int: 'NumberOfCondensationNodes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.NumberOfCondensationNodes

    @property
    def datum(self) -> 'list_with_selected_item.ListWithSelectedItem_Datum':
        '''list_with_selected_item.ListWithSelectedItem_Datum: 'Datum' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_Datum)(self.wrapped.Datum) if self.wrapped.Datum else None

    @datum.setter
    def datum(self, value: 'list_with_selected_item.ListWithSelectedItem_Datum.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_Datum.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_Datum.implicit_type()
        value = wrapper_type[enclosed_type](value.wrapped if value else None)
        self.wrapped.Datum = value

    @property
    def copy_datum_to_manual(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'CopyDatumToManual' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CopyDatumToManual

    @property
    def alignment_method(self) -> '_1907.AlignmentMethod':
        '''AlignmentMethod: 'AlignmentMethod' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.AlignmentMethod)
        return constructor.new(_1907.AlignmentMethod)(value) if value else None

    @alignment_method.setter
    def alignment_method(self, value: '_1907.AlignmentMethod'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.AlignmentMethod = value

    @property
    def component_to_align_to(self) -> 'list_with_selected_item.ListWithSelectedItem_Component':
        '''list_with_selected_item.ListWithSelectedItem_Component: 'ComponentToAlignTo' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_Component)(self.wrapped.ComponentToAlignTo) if self.wrapped.ComponentToAlignTo else None

    @component_to_align_to.setter
    def component_to_align_to(self, value: 'list_with_selected_item.ListWithSelectedItem_Component.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_Component.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_Component.implicit_type()
        value = wrapper_type[enclosed_type](value.wrapped if value else None)
        self.wrapped.ComponentToAlignTo = value

    @property
    def delete_all_links(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'DeleteAllLinks' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DeleteAllLinks

    @property
    def full_fe_model_mesh_size(self) -> 'str':
        '''str: 'FullFEModelMeshSize' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FullFEModelMeshSize

    @property
    def full_fe_model_vectors_size(self) -> 'str':
        '''str: 'FullFEModelVectorsSize' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.FullFEModelVectorsSize

    @property
    def embed_fe_model_mesh_in_masta_file(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'EmbedFEModelMeshInMASTAFile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EmbedFEModelMeshInMASTAFile

    @property
    def embed_fe_model_vectors_in_masta_file(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'EmbedFEModelVectorsInMASTAFile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.EmbedFEModelVectorsInMASTAFile

    @property
    def store_full_fe_model_mesh_in_external_file(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'StoreFullFEModelMeshInExternalFile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StoreFullFEModelMeshInExternalFile

    @property
    def store_full_fe_model_vectors_in_external_file(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'StoreFullFEModelVectorsInExternalFile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.StoreFullFEModelVectorsInExternalFile

    @property
    def unload_external_mesh_file(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'UnloadExternalMeshFile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.UnloadExternalMeshFile

    @property
    def load_external_mesh_file(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'LoadExternalMeshFile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadExternalMeshFile

    @property
    def unload_external_vectors_file(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'UnloadExternalVectorsFile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.UnloadExternalVectorsFile

    @property
    def load_external_vectors_file(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'LoadExternalVectorsFile' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.LoadExternalVectorsFile

    @property
    def remove_full_fe_mesh(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'RemoveFullFEMesh' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RemoveFullFEMesh

    @property
    def number_of_angles(self) -> 'int':
        '''int: 'NumberOfAngles' is the original name of this property.'''

        return self.wrapped.NumberOfAngles

    @number_of_angles.setter
    def number_of_angles(self, value: 'int'):
        self.wrapped.NumberOfAngles = int(value) if value else 0

    @property
    def angle_span(self) -> 'float':
        '''float: 'AngleSpan' is the original name of this property.'''

        return self.wrapped.AngleSpan

    @angle_span.setter
    def angle_span(self, value: 'float'):
        self.wrapped.AngleSpan = float(value) if value else 0.0

    @property
    def condensation_node_size(self) -> 'float':
        '''float: 'CondensationNodeSize' is the original name of this property.'''

        return self.wrapped.CondensationNodeSize

    @condensation_node_size.setter
    def condensation_node_size(self, value: 'float'):
        self.wrapped.CondensationNodeSize = float(value) if value else 0.0

    @property
    def create_datum_from_manual_alignment(self) -> 'Callable[[], None]':
        '''Callable[[], None]: 'CreateDatumFromManualAlignment' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.CreateDatumFromManualAlignment

    @property
    def bearing_races_in_fe(self) -> 'bool':
        '''bool: 'BearingRacesInFE' is the original name of this property.'''

        return self.wrapped.BearingRacesInFE

    @bearing_races_in_fe.setter
    def bearing_races_in_fe(self, value: 'bool'):
        self.wrapped.BearingRacesInFE = bool(value) if value else False

    @property
    def is_mesh_loaded(self) -> 'bool':
        '''bool: 'IsMeshLoaded' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IsMeshLoaded

    @property
    def are_vectors_loaded(self) -> 'bool':
        '''bool: 'AreVectorsLoaded' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AreVectorsLoaded

    @property
    def fe_meshing_options(self) -> '_1367.FEMeshingOptions':
        '''FEMeshingOptions: 'FEMeshingOptions' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1367.FEMeshingOptions)(self.wrapped.FEMeshingOptions) if self.wrapped.FEMeshingOptions else None

    @property
    def cms_model(self) -> '_1491.FullFEModel':
        '''FullFEModel: 'CMSModel' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1491.FullFEModel)(self.wrapped.CMSModel) if self.wrapped.CMSModel else None

    @property
    def alignment_to_component(self) -> '_1806.RelativeComponentAlignment[_1986.Component]':
        '''RelativeComponentAlignment[Component]: 'AlignmentToComponent' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1806.RelativeComponentAlignment)[_1986.Component](self.wrapped.AlignmentToComponent) if self.wrapped.AlignmentToComponent else None

    @property
    def alignment_using_axial_node_positions(self) -> '_1909.AlignmentUsingAxialNodePositions':
        '''AlignmentUsingAxialNodePositions: 'AlignmentUsingAxialNodePositions' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1909.AlignmentUsingAxialNodePositions)(self.wrapped.AlignmentUsingAxialNodePositions) if self.wrapped.AlignmentUsingAxialNodePositions else None

    @property
    def coordinate_system(self) -> '_1061.CoordinateSystem3D':
        '''CoordinateSystem3D: 'CoordinateSystem' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1061.CoordinateSystem3D)(self.wrapped.CoordinateSystem) if self.wrapped.CoordinateSystem else None

    @property
    def export(self) -> '_1970.UsedForExportingAnImportedFEsSetupOrSubstructuringStepToAnFEFile':
        '''UsedForExportingAnImportedFEsSetupOrSubstructuringStepToAnFEFile: 'Export' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1970.UsedForExportingAnImportedFEsSetupOrSubstructuringStepToAnFEFile)(self.wrapped.Export) if self.wrapped.Export else None

    @property
    def acoustic_radiation_efficiency(self) -> '_44.AcousticRadiationEfficiency':
        '''AcousticRadiationEfficiency: 'AcousticRadiationEfficiency' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_44.AcousticRadiationEfficiency)(self.wrapped.AcousticRadiationEfficiency) if self.wrapped.AcousticRadiationEfficiency else None

    @property
    def sound_pressure_enclosure(self) -> '_88.SoundPressureEnclosure':
        '''SoundPressureEnclosure: 'SoundPressureEnclosure' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_88.SoundPressureEnclosure)(self.wrapped.SoundPressureEnclosure) if self.wrapped.SoundPressureEnclosure else None

    @property
    def shafts_that_can_be_replaced(self) -> 'List[_1965.ReplacedShaftSelectionHelper]':
        '''List[ReplacedShaftSelectionHelper]: 'ShaftsThatCanBeReplaced' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ShaftsThatCanBeReplaced, constructor.new(_1965.ReplacedShaftSelectionHelper))
        return value

    @property
    def nodes(self) -> 'List[_1944.ImportedFEStiffnessNode]':
        '''List[ImportedFEStiffnessNode]: 'Nodes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Nodes, constructor.new(_1944.ImportedFEStiffnessNode))
        return value

    @property
    def replaced_shafts(self) -> 'List[_2019.Shaft]':
        '''List[Shaft]: 'ReplacedShafts' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ReplacedShafts, constructor.new(_2019.Shaft))
        return value

    @property
    def links(self) -> 'List[_1905.ImportedFELink]':
        '''List[ImportedFELink]: 'Links' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Links, constructor.new(_1905.ImportedFELink))
        return value

    @property
    def thermal_expansion_forces(self) -> 'List[_1116.VectorWithLinearAndAngularComponents]':
        '''List[VectorWithLinearAndAngularComponents]: 'ThermalExpansionForces' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ThermalExpansionForces, constructor.new(_1116.VectorWithLinearAndAngularComponents))
        return value

    @property
    def thermal_expansion_displacements(self) -> 'List[_1116.VectorWithLinearAndAngularComponents]':
        '''List[VectorWithLinearAndAngularComponents]: 'ThermalExpansionDisplacements' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ThermalExpansionDisplacements, constructor.new(_1116.VectorWithLinearAndAngularComponents))
        return value

    @property
    def geometries(self) -> 'List[_1929.FEStiffnessGeometry]':
        '''List[FEStiffnessGeometry]: 'Geometries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Geometries, constructor.new(_1929.FEStiffnessGeometry))
        return value

    @property
    def gear_meshing_options(self) -> 'List[_1931.GearMeshingOptions]':
        '''List[GearMeshingOptions]: 'GearMeshingOptions' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.GearMeshingOptions, constructor.new(_1931.GearMeshingOptions))
        return value

    @property
    def independent_masta_created_condensation_nodes(self) -> 'List[_1951.IndependentMastaCreatedCondensationNode]':
        '''List[IndependentMastaCreatedCondensationNode]: 'IndependentMastaCreatedCondensationNodes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.IndependentMastaCreatedCondensationNodes, constructor.new(_1951.IndependentMastaCreatedCondensationNode))
        return value

    @property
    def imported_fe_component(self) -> '_1998.ImportedFEComponent':
        '''ImportedFEComponent: 'ImportedFEComponent' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1998.ImportedFEComponent)(self.wrapped.ImportedFEComponent) if self.wrapped.ImportedFEComponent else None

    def store_full_fe_mesh_in_external_file(self, external_fe_path: 'str'):
        ''' 'StoreFullFeMeshInExternalFile' is the original name of this method.

        Args:
            external_fe_path (str)
        '''

        external_fe_path = str(external_fe_path)
        self.wrapped.StoreFullFeMeshInExternalFile(external_fe_path if external_fe_path else None)

    def load_existing_masta_fe_file(self, file_name: 'str'):
        ''' 'LoadExistingMastaFEFile' is the original name of this method.

        Args:
            file_name (str)
        '''

        file_name = str(file_name)
        self.wrapped.LoadExistingMastaFEFile(file_name if file_name else None)

    def load_existing_masta_fe_file_with_progress(self, file_name: 'str', progress: '_6498.TaskProgress'):
        ''' 'LoadExistingMastaFEFile' is the original name of this method.

        Args:
            file_name (str)
            progress (mastapy.TaskProgress)
        '''

        file_name = str(file_name)
        self.wrapped.LoadExistingMastaFEFile(file_name if file_name else None, progress.wrapped if progress else None)

    def create_imported_fe_with_selection_static_analysis(self) -> '_1950.ImportedFEWithSelectionStaticAnalysis':
        ''' 'CreateImportedFEWithSelectionStaticAnalysis' is the original name of this method.

        Returns:
            mastapy.system_model.imported_fes.ImportedFEWithSelectionStaticAnalysis
        '''

        method_result = self.wrapped.CreateImportedFEWithSelectionStaticAnalysis()
        return constructor.new(_1950.ImportedFEWithSelectionStaticAnalysis)(method_result) if method_result else None

    def create_imported_fe_with_selection_components(self) -> '_1947.ImportedFEWithSelectionComponents':
        ''' 'CreateImportedFEWithSelectionComponents' is the original name of this method.

        Returns:
            mastapy.system_model.imported_fes.ImportedFEWithSelectionComponents
        '''

        method_result = self.wrapped.CreateImportedFEWithSelectionComponents()
        return constructor.new(_1947.ImportedFEWithSelectionComponents)(method_result) if method_result else None

    def create_imported_fe_with_selection_for_harmonic_analysis(self) -> '_1948.ImportedFEWithSelectionForHarmonicAnalysis':
        ''' 'CreateImportedFEWithSelectionForHarmonicAnalysis' is the original name of this method.

        Returns:
            mastapy.system_model.imported_fes.ImportedFEWithSelectionForHarmonicAnalysis
        '''

        method_result = self.wrapped.CreateImportedFEWithSelectionForHarmonicAnalysis()
        return constructor.new(_1948.ImportedFEWithSelectionForHarmonicAnalysis)(method_result) if method_result else None

    def create_imported_fe_with_selection_modal_analysis(self) -> '_1949.ImportedFEWithSelectionModalAnalysis':
        ''' 'CreateImportedFEWithSelectionModalAnalysis' is the original name of this method.

        Returns:
            mastapy.system_model.imported_fes.ImportedFEWithSelectionModalAnalysis
        '''

        method_result = self.wrapped.CreateImportedFEWithSelectionModalAnalysis()
        return constructor.new(_1949.ImportedFEWithSelectionModalAnalysis)(method_result) if method_result else None

    def links_for(self, node: '_1944.ImportedFEStiffnessNode') -> 'List[_1905.ImportedFELink]':
        ''' 'LinksFor' is the original name of this method.

        Args:
            node (mastapy.system_model.imported_fes.ImportedFEStiffnessNode)

        Returns:
            List[mastapy.system_model.imported_fes.ImportedFELink]
        '''

        return conversion.pn_to_mp_objects_in_list(self.wrapped.LinksFor(node.wrapped if node else None), constructor.new(_1905.ImportedFELink))



'''_234.py

ISO10300SingleFlankRatingHypoidMethodB2
'''


from mastapy._internal import constructor
from mastapy.gears.rating.iso_10300 import _236
from mastapy._internal.python_net import python_net_import

_ISO10300_SINGLE_FLANK_RATING_HYPOID_METHOD_B2 = python_net_import('SMT.MastaAPI.Gears.Rating.Iso10300', 'ISO10300SingleFlankRatingHypoidMethodB2')


__docformat__ = 'restructuredtext en'
__all__ = ('ISO10300SingleFlankRatingHypoidMethodB2',)


class ISO10300SingleFlankRatingHypoidMethodB2(_236.ISO10300SingleFlankRatingMethodB2):
    '''ISO10300SingleFlankRatingHypoidMethodB2

    This is a mastapy class.
    '''

    TYPE = _ISO10300_SINGLE_FLANK_RATING_HYPOID_METHOD_B2

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ISO10300SingleFlankRatingHypoidMethodB2.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def intermediate_value_sub_dsub(self) -> 'float':
        '''float: 'IntermediateValueSubDsub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IntermediateValueSubDsub

    @property
    def intermediate_value_sub_csub(self) -> 'float':
        '''float: 'IntermediateValueSubCsub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IntermediateValueSubCsub

    @property
    def intermediate_angle_subasub(self) -> 'float':
        '''float: 'IntermediateAngleSubasub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IntermediateAngleSubasub

    @property
    def intermediate_angle_different_between_sub_dsub_and(self) -> 'float':
        '''float: 'IntermediateAngleDifferentBetweenSubDsubAnd' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IntermediateAngleDifferentBetweenSubDsubAnd

    @property
    def intermediate_angle_different_between_sub_csub_and(self) -> 'float':
        '''float: 'IntermediateAngleDifferentBetweenSubCsubAnd' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IntermediateAngleDifferentBetweenSubCsubAnd

    @property
    def intermediate_value_gsub_1sub(self) -> 'float':
        '''float: 'IntermediateValueGsub1sub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.IntermediateValueGsub1sub

    @property
    def wheel_angle_between_centreline_and_fillet_point_on_drive_side(self) -> 'float':
        '''float: 'WheelAngleBetweenCentrelineAndFilletPointOnDriveSide' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelAngleBetweenCentrelineAndFilletPointOnDriveSide

    @property
    def wheel_angle_between_centreline_and_fillet_point_on_coast_side(self) -> 'float':
        '''float: 'WheelAngleBetweenCentrelineAndFilletPointOnCoastSide' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelAngleBetweenCentrelineAndFilletPointOnCoastSide

    @property
    def wheel_angle_between_fillet_point(self) -> 'float':
        '''float: 'WheelAngleBetweenFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelAngleBetweenFilletPoint

    @property
    def vertical_distance_from_pitch_circle_to_fillet_point(self) -> 'float':
        '''float: 'VerticalDistanceFromPitchCircleToFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VerticalDistanceFromPitchCircleToFilletPoint

    @property
    def horizontal_distance_from_centreline_to_fillet_point(self) -> 'float':
        '''float: 'HorizontalDistanceFromCentrelineToFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HorizontalDistanceFromCentrelineToFilletPoint

    @property
    def generated_pressure_angle_of_wheel_at_fillet_point(self) -> 'float':
        '''float: 'GeneratedPressureAngleOfWheelAtFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.GeneratedPressureAngleOfWheelAtFilletPoint

    @property
    def distance_from_centreline_to_tool_critical_drive_side_fillet_point(self) -> 'float':
        '''float: 'DistanceFromCentrelineToToolCriticalDriveSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DistanceFromCentrelineToToolCriticalDriveSideFilletPoint

    @property
    def distance_from_centreline_to_tool_critical_coast_side_fillet_point(self) -> 'float':
        '''float: 'DistanceFromCentrelineToToolCriticalCoastSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DistanceFromCentrelineToToolCriticalCoastSideFilletPoint

    @property
    def wheel_angle_between_centreline_and_critical_point_drive_side_fillet_point(self) -> 'float':
        '''float: 'WheelAngleBetweenCentrelineAndCriticalPointDriveSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelAngleBetweenCentrelineAndCriticalPointDriveSideFilletPoint

    @property
    def wheel_angle_between_centreline_and_critical_point_coast_side_fillet_point(self) -> 'float':
        '''float: 'WheelAngleBetweenCentrelineAndCriticalPointCoastSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelAngleBetweenCentrelineAndCriticalPointCoastSideFilletPoint

    @property
    def radius_from_tool_centre_to_critical_pinion_drive_side_fillet_point(self) -> 'float':
        '''float: 'RadiusFromToolCentreToCriticalPinionDriveSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RadiusFromToolCentreToCriticalPinionDriveSideFilletPoint

    @property
    def radius_from_tool_centre_to_critical_pinion_coast_side_fillet_point(self) -> 'float':
        '''float: 'RadiusFromToolCentreToCriticalPinionCoastSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.RadiusFromToolCentreToCriticalPinionCoastSideFilletPoint

    @property
    def wheel_angle_from_centreline_to_tooth_surface_at_critical_fillet_point_on_drive_side(self) -> 'float':
        '''float: 'WheelAngleFromCentrelineToToothSurfaceAtCriticalFilletPointOnDriveSide' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelAngleFromCentrelineToToothSurfaceAtCriticalFilletPointOnDriveSide

    @property
    def wheel_angle_from_centreline_to_tooth_surface_at_critical_fillet_point_on_coast_side(self) -> 'float':
        '''float: 'WheelAngleFromCentrelineToToothSurfaceAtCriticalFilletPointOnCoastSide' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelAngleFromCentrelineToToothSurfaceAtCriticalFilletPointOnCoastSide

    @property
    def pinion_angle_from_centreline_to_tooth_surface_at_critical_drive_side_fillet_point(self) -> 'float':
        '''float: 'PinionAngleFromCentrelineToToothSurfaceAtCriticalDriveSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionAngleFromCentrelineToToothSurfaceAtCriticalDriveSideFilletPoint

    @property
    def pinion_angle_from_centreline_to_tooth_surface_at_critical_coast_side_fillet_point(self) -> 'float':
        '''float: 'PinionAngleFromCentrelineToToothSurfaceAtCriticalCoastSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionAngleFromCentrelineToToothSurfaceAtCriticalCoastSideFilletPoint

    @property
    def wheel_difference_angle_between_tool_and_surface_at_drive_side_fillet_point(self) -> 'float':
        '''float: 'WheelDifferenceAngleBetweenToolAndSurfaceAtDriveSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelDifferenceAngleBetweenToolAndSurfaceAtDriveSideFilletPoint

    @property
    def wheel_difference_angle_between_tool_and_surface_at_coast_side_fillet_point(self) -> 'float':
        '''float: 'WheelDifferenceAngleBetweenToolAndSurfaceAtCoastSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelDifferenceAngleBetweenToolAndSurfaceAtCoastSideFilletPoint

    @property
    def pinion_difference_angle_between_tool_and_surface_at_drive_side_fillet_point(self) -> 'float':
        '''float: 'PinionDifferenceAngleBetweenToolAndSurfaceAtDriveSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionDifferenceAngleBetweenToolAndSurfaceAtDriveSideFilletPoint

    @property
    def pinion_difference_angle_between_tool_and_surface_at_coast_side_fillet_point(self) -> 'float':
        '''float: 'PinionDifferenceAngleBetweenToolAndSurfaceAtCoastSideFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionDifferenceAngleBetweenToolAndSurfaceAtCoastSideFilletPoint

    @property
    def pinion_angle_unbalance_between_fillet_point(self) -> 'float':
        '''float: 'PinionAngleUnbalanceBetweenFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionAngleUnbalanceBetweenFilletPoint

    @property
    def pinion_angle_from_centreline_to_pinion_tip(self) -> 'float':
        '''float: 'PinionAngleFromCentrelineToPinionTip' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionAngleFromCentrelineToPinionTip

    @property
    def wheel_angle_from_pinion_tip_to_point_of_load_application(self) -> 'float':
        '''float: 'WheelAngleFromPinionTipToPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelAngleFromPinionTipToPointOfLoadApplication

    @property
    def rsub_3sub(self) -> 'float':
        '''float: 'Rsub3sub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Rsub3sub

    @property
    def hsub_3sub(self) -> 'float':
        '''float: 'Hsub3sub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Hsub3sub

    @property
    def hsub_3osub(self) -> 'float':
        '''float: 'Hsub3osub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Hsub3osub

    @property
    def pinion_angle_from_wheel_tip_to_point_of_load_application(self) -> 'float':
        '''float: 'PinionAngleFromWheelTipToPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionAngleFromWheelTipToPointOfLoadApplication

    @property
    def rsub_4sub(self) -> 'float':
        '''float: 'Rsub4sub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Rsub4sub

    @property
    def hsub_4sub(self) -> 'float':
        '''float: 'Hsub4sub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Hsub4sub

    @property
    def hsub_4osub(self) -> 'float':
        '''float: 'Hsub4osub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Hsub4osub

    @property
    def distance_from_pitch_circle_to_point_of_load_application(self) -> 'float':
        '''float: 'DistanceFromPitchCircleToPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.DistanceFromPitchCircleToPointOfLoadApplication

    @property
    def angle_between_centreline_and_line_from_point_of_load_application_and_fillet_point_on_wheel(self) -> 'float':
        '''float: 'AngleBetweenCentrelineAndLineFromPointOfLoadApplicationAndFilletPointOnWheel' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AngleBetweenCentrelineAndLineFromPointOfLoadApplicationAndFilletPointOnWheel

    @property
    def wheel_horizontal_distance_from_centreline_to_critical_fillet_point(self) -> 'float':
        '''float: 'WheelHorizontalDistanceFromCentrelineToCriticalFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelHorizontalDistanceFromCentrelineToCriticalFilletPoint

    @property
    def vertical_distance_from_pitch_circle_to_critical_fillet_point(self) -> 'float':
        '''float: 'VerticalDistanceFromPitchCircleToCriticalFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VerticalDistanceFromPitchCircleToCriticalFilletPoint

    @property
    def wheel_load_height_at_weakest_section(self) -> 'float':
        '''float: 'WheelLoadHeightAtWeakestSection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelLoadHeightAtWeakestSection

    @property
    def auxiliary_value_hsub_n_2osub(self) -> 'float':
        '''float: 'AuxiliaryValueHsubN2osub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AuxiliaryValueHsubN2osub

    @property
    def wheel_tooth_strength_factor(self) -> 'float':
        '''float: 'WheelToothStrengthFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelToothStrengthFactor

    @property
    def pinion_angle_from_pitch_to_point_of_load_application(self) -> 'float':
        '''float: 'PinionAngleFromPitchToPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionAngleFromPitchToPointOfLoadApplication

    @property
    def pinion_pressure_angle_at_point_of_load_application(self) -> 'float':
        '''float: 'PinionPressureAngleAtPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionPressureAngleAtPointOfLoadApplication

    @property
    def pinion_radial_distance_to_point_of_load_application(self) -> 'float':
        '''float: 'PinionRadialDistanceToPointOfLoadApplication' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionRadialDistanceToPointOfLoadApplication

    @property
    def wheel_angle_between_centreline_and_pinion_fillet(self) -> 'float':
        '''float: 'WheelAngleBetweenCentrelineAndPinionFillet' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelAngleBetweenCentrelineAndPinionFillet

    @property
    def rsub_5sub(self) -> 'float':
        '''float: 'Rsub5sub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Rsub5sub

    @property
    def sub_d_2sub(self) -> 'float':
        '''float: 'SubD2sub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SubD2sub

    @property
    def sub_dsub(self) -> 'float':
        '''float: 'SubDsub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SubDsub

    @property
    def sub_dosub(self) -> 'float':
        '''float: 'SubDosub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.SubDosub

    @property
    def pinion_angle_between_centreline_and_pinion_fillet(self) -> 'float':
        '''float: 'PinionAngleBetweenCentrelineAndPinionFillet' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionAngleBetweenCentrelineAndPinionFillet

    @property
    def wheel_rotation_through_path_of_action(self) -> 'float':
        '''float: 'WheelRotationThroughPathOfAction' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelRotationThroughPathOfAction

    @property
    def wheel_angle_difference_between_path_of_action_and_tooth_surface_at_pinion_fillet(self) -> 'float':
        '''float: 'WheelAngleDifferenceBetweenPathOfActionAndToothSurfaceAtPinionFillet' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelAngleDifferenceBetweenPathOfActionAndToothSurfaceAtPinionFillet

    @property
    def wheel_radius_to_pinion_fillet_point(self) -> 'float':
        '''float: 'WheelRadiusToPinionFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.WheelRadiusToPinionFilletPoint

    @property
    def pinion_angle_to_fillet_point(self) -> 'float':
        '''float: 'PinionAngleToFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionAngleToFilletPoint

    @property
    def pinion_radius_to_fillet_point(self) -> 'float':
        '''float: 'PinionRadiusToFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionRadiusToFilletPoint

    @property
    def pinion_angle_from_centreline_to_fillet_point(self) -> 'float':
        '''float: 'PinionAngleFromCentrelineToFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionAngleFromCentrelineToFilletPoint

    @property
    def angle_between_centreline_and_line_from_point_of_load_application_and_fillet_point_on_pinion(self) -> 'float':
        '''float: 'AngleBetweenCentrelineAndLineFromPointOfLoadApplicationAndFilletPointOnPinion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AngleBetweenCentrelineAndLineFromPointOfLoadApplicationAndFilletPointOnPinion

    @property
    def pinion_horizontal_distance_to_critical_fillet_point(self) -> 'float':
        '''float: 'PinionHorizontalDistanceToCriticalFilletPoint' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionHorizontalDistanceToCriticalFilletPoint

    @property
    def pinion_load_height_at_weakest_section(self) -> 'float':
        '''float: 'PinionLoadHeightAtWeakestSection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionLoadHeightAtWeakestSection

    @property
    def auxiliary_value_hsub_n_1osub(self) -> 'float':
        '''float: 'AuxiliaryValueHsubN1osub' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AuxiliaryValueHsubN1osub

    @property
    def pinion_tooth_strength_factor(self) -> 'float':
        '''float: 'PinionToothStrengthFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PinionToothStrengthFactor

    @property
    def tooth_form_factor_for_hypoid_gear(self) -> 'float':
        '''float: 'ToothFormFactorForHypoidGear' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ToothFormFactorForHypoidGear

    @property
    def mean_face_width(self) -> 'float':
        '''float: 'MeanFaceWidth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MeanFaceWidth

    @property
    def contact_shift_due_to_load_for_pinion(self) -> 'float':
        '''float: 'ContactShiftDueToLoadForPinion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ContactShiftDueToLoadForPinion

    @property
    def contact_shift_due_to_load_for_wheel(self) -> 'float':
        '''float: 'ContactShiftDueToLoadForWheel' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ContactShiftDueToLoadForWheel

    @property
    def transverse_radius_to_point_of_load_application_for_pinion(self) -> 'float':
        '''float: 'TransverseRadiusToPointOfLoadApplicationForPinion' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransverseRadiusToPointOfLoadApplicationForPinion

    @property
    def transverse_radius_to_point_of_load_application_for_wheel(self) -> 'float':
        '''float: 'TransverseRadiusToPointOfLoadApplicationForWheel' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TransverseRadiusToPointOfLoadApplicationForWheel



'''_12.py

FkmSnCurveModel
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_FKM_SN_CURVE_MODEL = python_net_import('SMT.MastaAPI.Shafts', 'FkmSnCurveModel')


__docformat__ = 'restructuredtext en'
__all__ = ('FkmSnCurveModel',)


class FkmSnCurveModel(Enum):
    '''FkmSnCurveModel

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _FKM_SN_CURVE_MODEL

    __hash__ = None

    MODEL_I = 0
    MODEL_II = 1



'''_216.py

KlingelnbergCycloPalloidConicalGearSetRating
'''


from mastapy._internal import constructor
from mastapy.gears.rating.conical import _326
from mastapy._internal.python_net import python_net_import

_KLINGELNBERG_CYCLO_PALLOID_CONICAL_GEAR_SET_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.KlingelnbergConical', 'KlingelnbergCycloPalloidConicalGearSetRating')


__docformat__ = 'restructuredtext en'
__all__ = ('KlingelnbergCycloPalloidConicalGearSetRating',)


class KlingelnbergCycloPalloidConicalGearSetRating(_326.ConicalGearSetRating):
    '''KlingelnbergCycloPalloidConicalGearSetRating

    This is a mastapy class.
    '''

    TYPE = _KLINGELNBERG_CYCLO_PALLOID_CONICAL_GEAR_SET_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KlingelnbergCycloPalloidConicalGearSetRating.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def rating(self) -> 'str':
        '''str: 'Rating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Rating



'''_4971.py

BearingStiffnessModel
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_BEARING_STIFFNESS_MODEL = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses', 'BearingStiffnessModel')


__docformat__ = 'restructuredtext en'
__all__ = ('BearingStiffnessModel',)


class BearingStiffnessModel(Enum):
    '''BearingStiffnessModel

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _BEARING_STIFFNESS_MODEL

    __hash__ = None

    LINEAR_CONCEPT_BEARINGS = 0
    SYSTEM_DEFLECTION_RESULT = 1
    NONLINEAR_BEARING_MODEL = 2
    LOAD_CASE_SETTING = 3



'''_5282.py

ConicalGearMeshGearWhineAnalysis
'''


from typing import List

from mastapy.system_model.connections_and_sockets.gears import (
    _1866, _1858, _1860, _1862,
    _1874, _1877, _1878, _1879,
    _1882, _1884, _1886, _1890
)
from mastapy._internal import constructor, conversion
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.system_deflections import (
    _2236, _2206, _2213, _2218,
    _2268, _2273, _2276, _2279,
    _2308, _2314, _2317, _2340
)
from mastapy.system_model.analyses_and_results.gear_whine_analyses import _5316
from mastapy._internal.python_net import python_net_import

_CONICAL_GEAR_MESH_GEAR_WHINE_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.GearWhineAnalyses', 'ConicalGearMeshGearWhineAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('ConicalGearMeshGearWhineAnalysis',)


class ConicalGearMeshGearWhineAnalysis(_5316.GearMeshGearWhineAnalysis):
    '''ConicalGearMeshGearWhineAnalysis

    This is a mastapy class.
    '''

    TYPE = _CONICAL_GEAR_MESH_GEAR_WHINE_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConicalGearMeshGearWhineAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def connection_design(self) -> '_1866.ConicalGearMesh':
        '''ConicalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1866.ConicalGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_agma_gleason_conical_gear_mesh(self) -> '_1858.AGMAGleasonConicalGearMesh':
        '''AGMAGleasonConicalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1858.AGMAGleasonConicalGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to AGMAGleasonConicalGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1858.AGMAGleasonConicalGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_bevel_differential_gear_mesh(self) -> '_1860.BevelDifferentialGearMesh':
        '''BevelDifferentialGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1860.BevelDifferentialGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to BevelDifferentialGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1860.BevelDifferentialGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_bevel_gear_mesh(self) -> '_1862.BevelGearMesh':
        '''BevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1862.BevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to BevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1862.BevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_hypoid_gear_mesh(self) -> '_1874.HypoidGearMesh':
        '''HypoidGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1874.HypoidGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to HypoidGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1874.HypoidGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_klingelnberg_cyclo_palloid_conical_gear_mesh(self) -> '_1877.KlingelnbergCycloPalloidConicalGearMesh':
        '''KlingelnbergCycloPalloidConicalGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1877.KlingelnbergCycloPalloidConicalGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to KlingelnbergCycloPalloidConicalGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1877.KlingelnbergCycloPalloidConicalGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_klingelnberg_cyclo_palloid_hypoid_gear_mesh(self) -> '_1878.KlingelnbergCycloPalloidHypoidGearMesh':
        '''KlingelnbergCycloPalloidHypoidGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1878.KlingelnbergCycloPalloidHypoidGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to KlingelnbergCycloPalloidHypoidGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1878.KlingelnbergCycloPalloidHypoidGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh(self) -> '_1879.KlingelnbergCycloPalloidSpiralBevelGearMesh':
        '''KlingelnbergCycloPalloidSpiralBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1879.KlingelnbergCycloPalloidSpiralBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to KlingelnbergCycloPalloidSpiralBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1879.KlingelnbergCycloPalloidSpiralBevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_spiral_bevel_gear_mesh(self) -> '_1882.SpiralBevelGearMesh':
        '''SpiralBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1882.SpiralBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to SpiralBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1882.SpiralBevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_straight_bevel_diff_gear_mesh(self) -> '_1884.StraightBevelDiffGearMesh':
        '''StraightBevelDiffGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1884.StraightBevelDiffGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to StraightBevelDiffGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1884.StraightBevelDiffGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_straight_bevel_gear_mesh(self) -> '_1886.StraightBevelGearMesh':
        '''StraightBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1886.StraightBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to StraightBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1886.StraightBevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_design_of_type_zerol_bevel_gear_mesh(self) -> '_1890.ZerolBevelGearMesh':
        '''ZerolBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1890.ZerolBevelGearMesh.TYPE not in self.wrapped.ConnectionDesign.__class__.__mro__:
            raise CastException('Failed to cast connection_design to ZerolBevelGearMesh. Expected: {}.'.format(self.wrapped.ConnectionDesign.__class__.__qualname__))

        return constructor.new(_1890.ZerolBevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def planetaries(self) -> 'List[ConicalGearMeshGearWhineAnalysis]':
        '''List[ConicalGearMeshGearWhineAnalysis]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(ConicalGearMeshGearWhineAnalysis))
        return value

    @property
    def system_deflection_results(self) -> '_2236.ConicalGearMeshSystemDeflection':
        '''ConicalGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2236.ConicalGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_agma_gleason_conical_gear_mesh_system_deflection(self) -> '_2206.AGMAGleasonConicalGearMeshSystemDeflection':
        '''AGMAGleasonConicalGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2206.AGMAGleasonConicalGearMeshSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to AGMAGleasonConicalGearMeshSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2206.AGMAGleasonConicalGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_bevel_differential_gear_mesh_system_deflection(self) -> '_2213.BevelDifferentialGearMeshSystemDeflection':
        '''BevelDifferentialGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2213.BevelDifferentialGearMeshSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to BevelDifferentialGearMeshSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2213.BevelDifferentialGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_bevel_gear_mesh_system_deflection(self) -> '_2218.BevelGearMeshSystemDeflection':
        '''BevelGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2218.BevelGearMeshSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to BevelGearMeshSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2218.BevelGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_hypoid_gear_mesh_system_deflection(self) -> '_2268.HypoidGearMeshSystemDeflection':
        '''HypoidGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2268.HypoidGearMeshSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to HypoidGearMeshSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2268.HypoidGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_klingelnberg_cyclo_palloid_conical_gear_mesh_system_deflection(self) -> '_2273.KlingelnbergCycloPalloidConicalGearMeshSystemDeflection':
        '''KlingelnbergCycloPalloidConicalGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2273.KlingelnbergCycloPalloidConicalGearMeshSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to KlingelnbergCycloPalloidConicalGearMeshSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2273.KlingelnbergCycloPalloidConicalGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_klingelnberg_cyclo_palloid_hypoid_gear_mesh_system_deflection(self) -> '_2276.KlingelnbergCycloPalloidHypoidGearMeshSystemDeflection':
        '''KlingelnbergCycloPalloidHypoidGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2276.KlingelnbergCycloPalloidHypoidGearMeshSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to KlingelnbergCycloPalloidHypoidGearMeshSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2276.KlingelnbergCycloPalloidHypoidGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_system_deflection(self) -> '_2279.KlingelnbergCycloPalloidSpiralBevelGearMeshSystemDeflection':
        '''KlingelnbergCycloPalloidSpiralBevelGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2279.KlingelnbergCycloPalloidSpiralBevelGearMeshSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to KlingelnbergCycloPalloidSpiralBevelGearMeshSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2279.KlingelnbergCycloPalloidSpiralBevelGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_spiral_bevel_gear_mesh_system_deflection(self) -> '_2308.SpiralBevelGearMeshSystemDeflection':
        '''SpiralBevelGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2308.SpiralBevelGearMeshSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to SpiralBevelGearMeshSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2308.SpiralBevelGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_straight_bevel_diff_gear_mesh_system_deflection(self) -> '_2314.StraightBevelDiffGearMeshSystemDeflection':
        '''StraightBevelDiffGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2314.StraightBevelDiffGearMeshSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to StraightBevelDiffGearMeshSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2314.StraightBevelDiffGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_straight_bevel_gear_mesh_system_deflection(self) -> '_2317.StraightBevelGearMeshSystemDeflection':
        '''StraightBevelGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2317.StraightBevelGearMeshSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to StraightBevelGearMeshSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2317.StraightBevelGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None

    @property
    def system_deflection_results_of_type_zerol_bevel_gear_mesh_system_deflection(self) -> '_2340.ZerolBevelGearMeshSystemDeflection':
        '''ZerolBevelGearMeshSystemDeflection: 'SystemDeflectionResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2340.ZerolBevelGearMeshSystemDeflection.TYPE not in self.wrapped.SystemDeflectionResults.__class__.__mro__:
            raise CastException('Failed to cast system_deflection_results to ZerolBevelGearMeshSystemDeflection. Expected: {}.'.format(self.wrapped.SystemDeflectionResults.__class__.__qualname__))

        return constructor.new(_2340.ZerolBevelGearMeshSystemDeflection)(self.wrapped.SystemDeflectionResults) if self.wrapped.SystemDeflectionResults else None



'''_5902.py

SynchroniserSleeveDynamicAnalysis
'''


from mastapy.system_model.part_model.couplings import _2136
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6193
from mastapy.system_model.analyses_and_results.dynamic_analyses import _5901
from mastapy._internal.python_net import python_net_import

_SYNCHRONISER_SLEEVE_DYNAMIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.DynamicAnalyses', 'SynchroniserSleeveDynamicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('SynchroniserSleeveDynamicAnalysis',)


class SynchroniserSleeveDynamicAnalysis(_5901.SynchroniserPartDynamicAnalysis):
    '''SynchroniserSleeveDynamicAnalysis

    This is a mastapy class.
    '''

    TYPE = _SYNCHRONISER_SLEEVE_DYNAMIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SynchroniserSleeveDynamicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2136.SynchroniserSleeve':
        '''SynchroniserSleeve: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2136.SynchroniserSleeve)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_load_case(self) -> '_6193.SynchroniserSleeveLoadCase':
        '''SynchroniserSleeveLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6193.SynchroniserSleeveLoadCase)(self.wrapped.ComponentLoadCase) if self.wrapped.ComponentLoadCase else None



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3213 import AbstractAssemblyPowerFlow
    from ._3214 import AbstractShaftOrHousingPowerFlow
    from ._3215 import AGMAGleasonConicalGearMeshPowerFlow
    from ._3216 import AGMAGleasonConicalGearPowerFlow
    from ._3217 import AGMAGleasonConicalGearSetPowerFlow
    from ._3218 import AssemblyPowerFlow
    from ._3219 import BearingPowerFlow
    from ._3220 import BeltConnectionPowerFlow
    from ._3221 import BeltDrivePowerFlow
    from ._3222 import BevelDifferentialGearMeshPowerFlow
    from ._3223 import BevelDifferentialGearPowerFlow
    from ._3224 import BevelDifferentialGearSetPowerFlow
    from ._3225 import BevelDifferentialPlanetGearPowerFlow
    from ._3226 import BevelDifferentialSunGearPowerFlow
    from ._3227 import BevelGearMeshPowerFlow
    from ._3228 import BevelGearPowerFlow
    from ._3229 import BevelGearSetPowerFlow
    from ._3230 import BoltedJointPowerFlow
    from ._3231 import BoltPowerFlow
    from ._3232 import ClutchConnectionPowerFlow
    from ._3233 import ClutchHalfPowerFlow
    from ._3234 import ClutchPowerFlow
    from ._3235 import CoaxialConnectionPowerFlow
    from ._3236 import ComponentPowerFlow
    from ._3237 import ConceptCouplingConnectionPowerFlow
    from ._3238 import ConceptCouplingHalfPowerFlow
    from ._3239 import ConceptCouplingPowerFlow
    from ._3240 import ConceptGearMeshPowerFlow
    from ._3241 import ConceptGearPowerFlow
    from ._3242 import ConceptGearSetPowerFlow
    from ._3243 import ConicalGearMeshPowerFlow
    from ._3244 import ConicalGearPowerFlow
    from ._3245 import ConicalGearSetPowerFlow
    from ._3246 import ConnectionPowerFlow
    from ._3247 import ConnectorPowerFlow
    from ._3248 import CouplingConnectionPowerFlow
    from ._3249 import CouplingHalfPowerFlow
    from ._3250 import CouplingPowerFlow
    from ._3251 import CVTBeltConnectionPowerFlow
    from ._3252 import CVTPowerFlow
    from ._3253 import CVTPulleyPowerFlow
    from ._3254 import CylindricalGearGeometricEntityDrawStyle
    from ._3255 import CylindricalGearMeshPowerFlow
    from ._3256 import CylindricalGearPowerFlow
    from ._3257 import CylindricalGearSetPowerFlow
    from ._3258 import CylindricalPlanetGearPowerFlow
    from ._3259 import DatumPowerFlow
    from ._3260 import ExternalCADModelPowerFlow
    from ._3261 import FaceGearMeshPowerFlow
    from ._3262 import FaceGearPowerFlow
    from ._3263 import FaceGearSetPowerFlow
    from ._3264 import FlexiblePinAssemblyPowerFlow
    from ._3265 import GearMeshPowerFlow
    from ._3266 import GearPowerFlow
    from ._3267 import GearSetPowerFlow
    from ._3268 import GuideDxfModelPowerFlow
    from ._3269 import HypoidGearMeshPowerFlow
    from ._3270 import HypoidGearPowerFlow
    from ._3271 import HypoidGearSetPowerFlow
    from ._3272 import ImportedFEComponentPowerFlow
    from ._3273 import InterMountableComponentConnectionPowerFlow
    from ._3274 import KlingelnbergCycloPalloidConicalGearMeshPowerFlow
    from ._3275 import KlingelnbergCycloPalloidConicalGearPowerFlow
    from ._3276 import KlingelnbergCycloPalloidConicalGearSetPowerFlow
    from ._3277 import KlingelnbergCycloPalloidHypoidGearMeshPowerFlow
    from ._3278 import KlingelnbergCycloPalloidHypoidGearPowerFlow
    from ._3279 import KlingelnbergCycloPalloidHypoidGearSetPowerFlow
    from ._3280 import KlingelnbergCycloPalloidSpiralBevelGearMeshPowerFlow
    from ._3281 import KlingelnbergCycloPalloidSpiralBevelGearPowerFlow
    from ._3282 import KlingelnbergCycloPalloidSpiralBevelGearSetPowerFlow
    from ._3283 import MassDiscPowerFlow
    from ._3284 import MeasurementComponentPowerFlow
    from ._3285 import MountableComponentPowerFlow
    from ._3286 import OilSealPowerFlow
    from ._3287 import PartPowerFlow
    from ._3288 import PartToPartShearCouplingConnectionPowerFlow
    from ._3289 import PartToPartShearCouplingHalfPowerFlow
    from ._3290 import PartToPartShearCouplingPowerFlow
    from ._3291 import PlanetaryConnectionPowerFlow
    from ._3292 import PlanetaryGearSetPowerFlow
    from ._3293 import PlanetCarrierPowerFlow
    from ._3294 import PointLoadPowerFlow
    from ._3295 import PowerFlow
    from ._3296 import PowerFlowDrawStyle
    from ._3297 import PowerLoadPowerFlow
    from ._3298 import PulleyPowerFlow
    from ._3299 import RollingRingAssemblyPowerFlow
    from ._3300 import RollingRingConnectionPowerFlow
    from ._3301 import RollingRingPowerFlow
    from ._3302 import RootAssemblyPowerFlow
    from ._3303 import ShaftHubConnectionPowerFlow
    from ._3304 import ShaftPowerFlow
    from ._3305 import ShaftToMountableComponentConnectionPowerFlow
    from ._3306 import SpecialisedAssemblyPowerFlow
    from ._3307 import SpiralBevelGearMeshPowerFlow
    from ._3308 import SpiralBevelGearPowerFlow
    from ._3309 import SpiralBevelGearSetPowerFlow
    from ._3310 import SpringDamperConnectionPowerFlow
    from ._3311 import SpringDamperHalfPowerFlow
    from ._3312 import SpringDamperPowerFlow
    from ._3313 import StraightBevelDiffGearMeshPowerFlow
    from ._3314 import StraightBevelDiffGearPowerFlow
    from ._3315 import StraightBevelDiffGearSetPowerFlow
    from ._3316 import StraightBevelGearMeshPowerFlow
    from ._3317 import StraightBevelGearPowerFlow
    from ._3318 import StraightBevelGearSetPowerFlow
    from ._3319 import StraightBevelPlanetGearPowerFlow
    from ._3320 import StraightBevelSunGearPowerFlow
    from ._3321 import SynchroniserHalfPowerFlow
    from ._3322 import SynchroniserPartPowerFlow
    from ._3323 import SynchroniserPowerFlow
    from ._3324 import SynchroniserSleevePowerFlow
    from ._3325 import ToothPassingHarmonic
    from ._3326 import TorqueConverterConnectionPowerFlow
    from ._3327 import TorqueConverterPowerFlow
    from ._3328 import TorqueConverterPumpPowerFlow
    from ._3329 import TorqueConverterTurbinePowerFlow
    from ._3330 import UnbalancedMassPowerFlow
    from ._3331 import VirtualComponentPowerFlow
    from ._3332 import WormGearMeshPowerFlow
    from ._3333 import WormGearPowerFlow
    from ._3334 import WormGearSetPowerFlow
    from ._3335 import ZerolBevelGearMeshPowerFlow
    from ._3336 import ZerolBevelGearPowerFlow
    from ._3337 import ZerolBevelGearSetPowerFlow



'''_6302.py

UseLtcaInAsdOption
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_USE_LTCA_IN_ASD_OPTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections', 'UseLtcaInAsdOption')


__docformat__ = 'restructuredtext en'
__all__ = ('UseLtcaInAsdOption',)


class UseLtcaInAsdOption(Enum):
    '''UseLtcaInAsdOption

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _USE_LTCA_IN_ASD_OPTION

    __hash__ = None

    NO = 0
    YES = 1
    AUTO = 2



'''_2648.py

GearCompoundSteadyStateSynchronousResponseOnAShaft
'''


from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft.compound import _2668
from mastapy._internal.python_net import python_net_import

_GEAR_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesOnAShaft.Compound', 'GearCompoundSteadyStateSynchronousResponseOnAShaft')


__docformat__ = 'restructuredtext en'
__all__ = ('GearCompoundSteadyStateSynchronousResponseOnAShaft',)


class GearCompoundSteadyStateSynchronousResponseOnAShaft(_2668.MountableComponentCompoundSteadyStateSynchronousResponseOnAShaft):
    '''GearCompoundSteadyStateSynchronousResponseOnAShaft

    This is a mastapy class.
    '''

    TYPE = _GEAR_COMPOUND_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearCompoundSteadyStateSynchronousResponseOnAShaft.TYPE'):
        super().__init__(instance_to_wrap)



'''_1863.py

BevelGearTeethSocket
'''


from mastapy.system_model.connections_and_sockets.gears import _1859
from mastapy._internal.python_net import python_net_import

_BEVEL_GEAR_TEETH_SOCKET = python_net_import('SMT.MastaAPI.SystemModel.ConnectionsAndSockets.Gears', 'BevelGearTeethSocket')


__docformat__ = 'restructuredtext en'
__all__ = ('BevelGearTeethSocket',)


class BevelGearTeethSocket(_1859.AGMAGleasonConicalGearTeethSocket):
    '''BevelGearTeethSocket

    This is a mastapy class.
    '''

    TYPE = _BEVEL_GEAR_TEETH_SOCKET

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BevelGearTeethSocket.TYPE'):
        super().__init__(instance_to_wrap)



'''_4941.py

StraightBevelDiffGearSetCompoundModalAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2082
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.modal_analyses.compound import _4939, _4940, _4858
from mastapy.system_model.analyses_and_results.modal_analyses import _4803
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_DIFF_GEAR_SET_COMPOUND_MODAL_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Compound', 'StraightBevelDiffGearSetCompoundModalAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelDiffGearSetCompoundModalAnalysis',)


class StraightBevelDiffGearSetCompoundModalAnalysis(_4858.BevelGearSetCompoundModalAnalysis):
    '''StraightBevelDiffGearSetCompoundModalAnalysis

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_DIFF_GEAR_SET_COMPOUND_MODAL_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelDiffGearSetCompoundModalAnalysis.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2082.StraightBevelDiffGearSet':
        '''StraightBevelDiffGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2082.StraightBevelDiffGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2082.StraightBevelDiffGearSet':
        '''StraightBevelDiffGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2082.StraightBevelDiffGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def straight_bevel_diff_gears_compound_modal_analysis(self) -> 'List[_4939.StraightBevelDiffGearCompoundModalAnalysis]':
        '''List[StraightBevelDiffGearCompoundModalAnalysis]: 'StraightBevelDiffGearsCompoundModalAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelDiffGearsCompoundModalAnalysis, constructor.new(_4939.StraightBevelDiffGearCompoundModalAnalysis))
        return value

    @property
    def straight_bevel_diff_meshes_compound_modal_analysis(self) -> 'List[_4940.StraightBevelDiffGearMeshCompoundModalAnalysis]':
        '''List[StraightBevelDiffGearMeshCompoundModalAnalysis]: 'StraightBevelDiffMeshesCompoundModalAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelDiffMeshesCompoundModalAnalysis, constructor.new(_4940.StraightBevelDiffGearMeshCompoundModalAnalysis))
        return value

    @property
    def load_case_analyses_ready(self) -> 'List[_4803.StraightBevelDiffGearSetModalAnalysis]':
        '''List[StraightBevelDiffGearSetModalAnalysis]: 'LoadCaseAnalysesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LoadCaseAnalysesReady, constructor.new(_4803.StraightBevelDiffGearSetModalAnalysis))
        return value

    @property
    def assembly_modal_analysis_load_cases(self) -> 'List[_4803.StraightBevelDiffGearSetModalAnalysis]':
        '''List[StraightBevelDiffGearSetModalAnalysis]: 'AssemblyModalAnalysisLoadCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyModalAnalysisLoadCases, constructor.new(_4803.StraightBevelDiffGearSetModalAnalysis))
        return value



'''_553.py

ShavingDynamicsViewModelBase
'''


from mastapy.gears.manufacturing.cylindrical import _411
from mastapy._internal.python_net import python_net_import

_SHAVING_DYNAMICS_VIEW_MODEL_BASE = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.AxialAndPlungeShavingDynamics', 'ShavingDynamicsViewModelBase')


__docformat__ = 'restructuredtext en'
__all__ = ('ShavingDynamicsViewModelBase',)


class ShavingDynamicsViewModelBase(_411.GearManufacturingConfigurationViewModel):
    '''ShavingDynamicsViewModelBase

    This is a mastapy class.
    '''

    TYPE = _SHAVING_DYNAMICS_VIEW_MODEL_BASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ShavingDynamicsViewModelBase.TYPE'):
        super().__init__(instance_to_wrap)



'''_1837.py

CylindricalComponentConnection
'''


from mastapy._internal.implicit import list_with_selected_item
from mastapy._internal import constructor
from mastapy.system_model.connections_and_sockets import _1832
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_COMPONENT_CONNECTION = python_net_import('SMT.MastaAPI.SystemModel.ConnectionsAndSockets', 'CylindricalComponentConnection')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalComponentConnection',)


class CylindricalComponentConnection(_1832.ComponentConnection):
    '''CylindricalComponentConnection

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_COMPONENT_CONNECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalComponentConnection.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def measuring_position_for_component(self) -> 'list_with_selected_item.ListWithSelectedItem_str':
        '''list_with_selected_item.ListWithSelectedItem_str: 'MeasuringPositionForComponent' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_str)(self.wrapped.MeasuringPositionForComponent) if self.wrapped.MeasuringPositionForComponent else None

    @measuring_position_for_component.setter
    def measuring_position_for_component(self, value: 'list_with_selected_item.ListWithSelectedItem_str.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else None)
        self.wrapped.MeasuringPositionForComponent = value

    @property
    def measuring_position_for_connected_component(self) -> 'list_with_selected_item.ListWithSelectedItem_str':
        '''list_with_selected_item.ListWithSelectedItem_str: 'MeasuringPositionForConnectedComponent' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_str)(self.wrapped.MeasuringPositionForConnectedComponent) if self.wrapped.MeasuringPositionForConnectedComponent else None

    @measuring_position_for_connected_component.setter
    def measuring_position_for_connected_component(self, value: 'list_with_selected_item.ListWithSelectedItem_str.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_str.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_str.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else None)
        self.wrapped.MeasuringPositionForConnectedComponent = value



'''_6398.py

CylindricalGearCompoundAdvancedSystemDeflection
'''


from typing import List

from mastapy.system_model.part_model.gears import _2061
from mastapy._internal import constructor, conversion
from mastapy.gears.rating.cylindrical import _255
from mastapy.system_model.analyses_and_results.advanced_system_deflections import _6273
from mastapy.system_model.analyses_and_results.advanced_system_deflections.compound import _6408
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_COMPOUND_ADVANCED_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.AdvancedSystemDeflections.Compound', 'CylindricalGearCompoundAdvancedSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearCompoundAdvancedSystemDeflection',)


class CylindricalGearCompoundAdvancedSystemDeflection(_6408.GearCompoundAdvancedSystemDeflection):
    '''CylindricalGearCompoundAdvancedSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_GEAR_COMPOUND_ADVANCED_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearCompoundAdvancedSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2061.CylindricalGear':
        '''CylindricalGear: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2061.CylindricalGear)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def gear_duty_cycle_rating(self) -> '_255.CylindricalGearDutyCycleRating':
        '''CylindricalGearDutyCycleRating: 'GearDutyCycleRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_255.CylindricalGearDutyCycleRating)(self.wrapped.GearDutyCycleRating) if self.wrapped.GearDutyCycleRating else None

    @property
    def cylindrical_gear_rating(self) -> '_255.CylindricalGearDutyCycleRating':
        '''CylindricalGearDutyCycleRating: 'CylindricalGearRating' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_255.CylindricalGearDutyCycleRating)(self.wrapped.CylindricalGearRating) if self.wrapped.CylindricalGearRating else None

    @property
    def load_case_analyses_ready(self) -> 'List[_6273.CylindricalGearAdvancedSystemDeflection]':
        '''List[CylindricalGearAdvancedSystemDeflection]: 'LoadCaseAnalysesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.LoadCaseAnalysesReady, constructor.new(_6273.CylindricalGearAdvancedSystemDeflection))
        return value

    @property
    def component_advanced_system_deflection_load_cases(self) -> 'List[_6273.CylindricalGearAdvancedSystemDeflection]':
        '''List[CylindricalGearAdvancedSystemDeflection]: 'ComponentAdvancedSystemDeflectionLoadCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ComponentAdvancedSystemDeflectionLoadCases, constructor.new(_6273.CylindricalGearAdvancedSystemDeflection))
        return value

    @property
    def planetaries(self) -> 'List[CylindricalGearCompoundAdvancedSystemDeflection]':
        '''List[CylindricalGearCompoundAdvancedSystemDeflection]: 'Planetaries' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.Planetaries, constructor.new(CylindricalGearCompoundAdvancedSystemDeflection))
        return value



'''_2511.py

CouplingHalfSteadyStateSynchronousResponseOnAShaft
'''


from mastapy.system_model.part_model.couplings import (
    _2116, _2111, _2114, _2118,
    _2120, _2121, _2127, _2131,
    _2134, _2135, _2136, _2138,
    _2140
)
from mastapy._internal import constructor
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import _2546
from mastapy._internal.python_net import python_net_import

_COUPLING_HALF_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesOnAShaft', 'CouplingHalfSteadyStateSynchronousResponseOnAShaft')


__docformat__ = 'restructuredtext en'
__all__ = ('CouplingHalfSteadyStateSynchronousResponseOnAShaft',)


class CouplingHalfSteadyStateSynchronousResponseOnAShaft(_2546.MountableComponentSteadyStateSynchronousResponseOnAShaft):
    '''CouplingHalfSteadyStateSynchronousResponseOnAShaft

    This is a mastapy class.
    '''

    TYPE = _COUPLING_HALF_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CouplingHalfSteadyStateSynchronousResponseOnAShaft.TYPE'):
        super().__init__(instance_to_wrap)

    @property
    def component_design(self) -> '_2116.CouplingHalf':
        '''CouplingHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2116.CouplingHalf)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_clutch_half(self) -> '_2111.ClutchHalf':
        '''ClutchHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2111.ClutchHalf.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to ClutchHalf. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2111.ClutchHalf)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_concept_coupling_half(self) -> '_2114.ConceptCouplingHalf':
        '''ConceptCouplingHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2114.ConceptCouplingHalf.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to ConceptCouplingHalf. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2114.ConceptCouplingHalf)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_cvt_pulley(self) -> '_2118.CVTPulley':
        '''CVTPulley: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2118.CVTPulley.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to CVTPulley. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2118.CVTPulley)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_part_to_part_shear_coupling_half(self) -> '_2120.PartToPartShearCouplingHalf':
        '''PartToPartShearCouplingHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2120.PartToPartShearCouplingHalf.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to PartToPartShearCouplingHalf. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2120.PartToPartShearCouplingHalf)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_pulley(self) -> '_2121.Pulley':
        '''Pulley: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2121.Pulley.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to Pulley. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2121.Pulley)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_rolling_ring(self) -> '_2127.RollingRing':
        '''RollingRing: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2127.RollingRing.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to RollingRing. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2127.RollingRing)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_spring_damper_half(self) -> '_2131.SpringDamperHalf':
        '''SpringDamperHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2131.SpringDamperHalf.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to SpringDamperHalf. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2131.SpringDamperHalf)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_synchroniser_half(self) -> '_2134.SynchroniserHalf':
        '''SynchroniserHalf: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2134.SynchroniserHalf.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to SynchroniserHalf. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2134.SynchroniserHalf)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_synchroniser_part(self) -> '_2135.SynchroniserPart':
        '''SynchroniserPart: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2135.SynchroniserPart.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to SynchroniserPart. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2135.SynchroniserPart)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_synchroniser_sleeve(self) -> '_2136.SynchroniserSleeve':
        '''SynchroniserSleeve: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2136.SynchroniserSleeve.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to SynchroniserSleeve. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2136.SynchroniserSleeve)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_torque_converter_pump(self) -> '_2138.TorqueConverterPump':
        '''TorqueConverterPump: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2138.TorqueConverterPump.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to TorqueConverterPump. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2138.TorqueConverterPump)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def component_design_of_type_torque_converter_turbine(self) -> '_2140.TorqueConverterTurbine':
        '''TorqueConverterTurbine: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _2140.TorqueConverterTurbine.TYPE not in self.wrapped.ComponentDesign.__class__.__mro__:
            raise CastException('Failed to cast component_design to TorqueConverterTurbine. Expected: {}.'.format(self.wrapped.ComponentDesign.__class__.__qualname__))

        return constructor.new(_2140.TorqueConverterTurbine)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1018 import KeyedJointDesign
    from ._1019 import KeyTypes
    from ._1020 import KeywayJointHalfDesign
    from ._1021 import NumberOfKeys
